A client-side stash that persists data in the browser's memory.
See the Browser Memory Adapter Guide for usage and
configuration details (source: docs/browser_memory.md).
A client-side stash that persists data in the browser's memory.
See the Browser Memory Adapter Guide for usage and
configuration details (source: docs/browser_memory.md).